# README.md:


#### NOTE: All **articles** are relocated into the FOLDER named 'Articles'
---

## GeigerLog 1.2.1 has been released!

> GeigerLog now supports all current Gamma-Scout Counters, including the lat­est “Online” model, the only one of the breed which allows logging.

> A SimulCounter has been added, which creates its “counts” with a Poisson random number generator. Helpful for understanding the workings of a Geiger counter and GeigerLog.

> Search the entire NotePad for the occurrence of a text like ‘abc’ or ‘123.456’

> The tool GLpipcheck was improved

> The Easter Holidays are approaching, and fittingly, an Easter egg can now be found in GeigerLog. Do your best – perhaps you will see a dancing GEIGERA?

---

## Placeholder
---

---

# single #

## double #

### triple #

#### quatrro #
---
